# test the require

print "Content-type: text/plain\n\n";

# XXX: fixme!
#use lib qw(.);
#my $file = "./local-conf.pl";
#require $file;

#print defined $test_require && $test_require;
print "it works";
